@@ -1,10 +1,10 @@
 package Random::Skew;
 
-use 5.028001;
+#use 5.028001;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 our $GRAIN = 24; # default
